@@ -2,6 +2,7 @@ from vcstools.general_utils import is_number
 import logging
 import os
 import subprocess
+from time import sleep
 
 logger = logging.getLogger(__name__)
 
@@ -38,7 +39,7 @@ def ensure_metafits(data_dir, obs_id, metafits_file):
         copy2("{0}".format(metafits_file), "{0}".format(data_dir))
 
 
-def singles_source_search(ra, dec=None, box_size=45., params=None):
+def singles_source_search(ra, dec=None, box_size=50., params=None):
     """
     Used to find all obsids within a box around the source to make searching through obs_ids more efficient.
 
@@ -91,12 +92,13 @@ def singles_source_search(ra, dec=None, box_size=45., params=None):
         ra_low = ra - 30. - box_size #30 is the how far an obs would drift in 2 hours(used as a max)
         ra_high = ra + box_size
         if ra_low < 0.:
-            ra_new = 360 + ra_low
+            ra_low = 360 + ra_low
         if ra_high > 360:
-            ra_new = ra_high - 360
+            ra_high = ra_high - 360
         params.update({'minra':ra_low,  'maxra':ra_high,
                        'mindec':dec_bot,'maxdec':dec_top})
     logger.debug("params: {}".format(params))
+    print("params: {}".format(params))
     obsid_list = find_obsids_meta_pages(params=params)
     return obsid_list
 
@@ -230,7 +232,7 @@ def get_common_obs_metadata(obsid, return_all=False, full_meta_data=None):
         return [obsid, ra, dec, dura, [xdelays, ydelays], centrefreq, channels]
 
 
-def getmeta(servicetype='metadata', service='obs', params=None):
+def getmeta(servicetype='metadata', service='obs', params=None, retries=3):
     """
     Function to call a JSON web service and return a dictionary:
     Given a JSON web service ('obs', find, or 'con') and a set of parameters as
@@ -250,14 +252,25 @@ def getmeta(servicetype='metadata', service='obs', params=None):
     else:
         data = ''
 
-    try:
-        result = json.load(urllib.request.urlopen(BASEURL + servicetype + '/' + service + '?' + data))
-    except urllib.error.HTTPError as err:
-        logger.error("HTTP error from server: code=%d, response:\n %s" % (err.code, err.read()))
-        return
-    except urllib.error.URLError as err:
-        logger.error("URL or network error: %s" % err.reason)
-        return
+    # Try several times (3 by default)
+    wait_time = 30
+    result = None
+    for x in range(0, retries):
+        err = False
+        try:
+            result = json.load(urllib.request.urlopen(BASEURL + servicetype + '/' + service + '?' + data))
+        except urllib.error.HTTPError as err:
+            logger.error("HTTP error from server: code=%d, response: %s" % (err.code, err.read()))
+            break
+        except urllib.error.URLError as err:
+            logger.error("URL or network error: %s" % err.reason)
+            logger.error("Waiting {} seconds and trying again".format(wait_time))
+            sleep(wait_time)
+            pass
+        else:
+            break
+    else:
+        logger.error("Tried {} times. Exiting.".format(retries))
 
     return result
 
